/// Copyright Thomas Nagy 2007
/// License: QPL
#ifndef szokilh
#define szokilh

#include <QTreeWidget>

#include     "co\
n.h"

#include <QToolBar>
class KTextEdit;
class ablkl;
class szkl : public QWidget
<%
	Q_OBJECT
	public:
		szkl(QWidget *felvnl, jelzpn *nybnvn);
		jelzpn *kidlgz;
		KTextEdit *fnqll;
		QLineEdit *hzzqjt;

		int jlzpnt;

		ablkl *akdaly;

		QToolBar *kitzjl;

		void mrtdt(const QTextCharFormat &prmz);

		QAction *vnl;
		QAction *prl;
		QAction *mgmnkl;

	public slots:
		void kivalt(const zagv&);
		void cel(const QString &);
		void megkap();

		void lnmtat();
		void kket();
		void bprl();

		void eler(const QTextCharFormat&);
%>;

#endif

